summaryrefslogtreecommitdiffstats
path: root/perl-install/pkgs.pm
diff options
context:
space:
mode:
Diffstat (limited to 'perl-install/pkgs.pm')
-rw-r--r--perl-install/pkgs.pm6
1 files changed, 3 insertions, 3 deletions
diff --git a/perl-install/pkgs.pm b/perl-install/pkgs.pm
index 9f097156f..2f0aeaaac 100644
--- a/perl-install/pkgs.pm
+++ b/perl-install/pkgs.pm
@@ -16,7 +16,7 @@ use c;
-my @preferred = qw(perl-GTK postfix proftpd ghostscript-X vim-minimal kernel db1 db2 ispell-en Bastille-Curses-module);
+my @preferred = qw(perl-GTK postfix proftpd ghostscript-X vim-minimal kernel db1 db2 ispell-en Bastille-Curses-module nautilus);
@preferred{@preferred} = ();
#- lower bound on the left ( aka 90 means [90-100[ )
@@ -786,8 +786,8 @@ sub computeGroupSize {
map { "$_&&$n" } @l;
} split('\|\|');
}
- #- HACK, remove LOCALES, too costly
- grep { !/LOCALES/ } @l;
+ #- HACK, remove LOCALES & CHARSET, too costly
+ grep { !/LOCALES|CHARSET/ } @l;
}
sub or_clean {
my (@l) = map { [ sort split('&&') ] } @_ or return '';